@@ -20,7 +20,7 @@ use File::Spec;
 @ISA = ('Exporter');
 @EXPORT = ('install','uninstall','pm_to_blib', 'install_default');
 
-=pod 
+=pod
 
 =head1 NAME
 
@@ -35,14 +35,14 @@ ExtUtils::Install - install files from here to there
   uninstall($packlist);
 
   pm_to_blib({ 'lib/Foo/Bar.pm' => 'blib/lib/Foo/Bar.pm' });
-    
+
 =head1 VERSION
 
-1.51
+1.64
 
 =cut
 
-$VERSION = '1.51';
+$VERSION = '1.64';  # <-- do not forget to update the POD section just above this line!
 $VERSION = eval $VERSION;
 
 =pod
@@ -57,7 +57,7 @@ ExtUtils::MakeMaker handles the installation and deinstallation of
 perl modules. They are not designed as general purpose tools.
 
 On some operating systems such as Win32 installation may not be possible
-until after a reboot has occured. This can have varying consequences:
+until after a reboot has occurred. This can have varying consequences:
 removing an old DLL does not impact programs using the new one, but if
 a new DLL cannot be installed properly until reboot then anything
 depending on it must wait. The package variable
@@ -66,13 +66,15 @@ depending on it must wait. The package variable
 
 is used to store this status.
 
-If this variable is true then such an operation has occured and
+If this variable is true then such an operation has occurred and
 anything depending on this module cannot proceed until a reboot
-has occured.
+has occurred.
 
 If this value is defined but false then such an operation has
 ocurred, but should not impact later operations.
 
+=over
+
 =begin _private
 
 =item _chmod($$;$)
@@ -87,6 +89,8 @@ Warns about something only once.
 
 Dies with a special message.
 
+=back
+
 =end _private
 
 =cut
@@ -135,16 +139,19 @@ sub _chmod($$;$) {
     my ( $mode, $item, $verbose )=@_;
     $verbose ||= 0;
     if (chmod $mode, $item) {
-        print "chmod($mode, $item)\n" if $verbose > 1;
+        printf "chmod(0%o, %s)\n",$mode, $item if $verbose > 1;
     } else {
         my $err="$!";
-        _warnonce "WARNING: Failed chmod($mode, $item): $err\n"
+        _warnonce sprintf "WARNING: Failed chmod(0%o, %s): %s\n",
+                  $mode, $item, $err
             if -e $item;
     }
 }
 
 =begin _private
 
+=over
+
 =item _move_file_at_boot( $file, $target, $moan  )
 
 OS-Specific, Win32/Cygwin
@@ -155,7 +162,7 @@ $target should be a ref to an array if the file is to be deleted
 otherwise it should be a filespec for a rename. If the file is existing
 it will be replaced.
 
-Sets $MUST_REBOOT to 0 to indicate a deletion operation has occured
+Sets $MUST_REBOOT to 0 to indicate a deletion operation has occurred
 and sets it to 1 to indicate that a move operation has been requested.
 
 returns 1 on success, on failure if $moan is false errors are fatal.
@@ -211,6 +218,7 @@ sub _move_file_at_boot { #XXX OS-SPECIFIC
 
 =begin _private
 
+
 =item _unlink_or_rename( $file, $tryhard, $installing )
 
 OS-Specific, Win32/Cygwin
@@ -264,7 +272,7 @@ sub _unlink_or_rename { #XXX OS-SPECIFIC
          "Going to try to rename it to '$tmp'.\n";
 
     if ( rename $file, $tmp ) {
-        warn "Rename succesful. Scheduling '$tmp'\nfor deletion at reboot.\n";
+        warn "Rename successful. Scheduling '$tmp'\nfor deletion at reboot.\n";
         # when $installing we can set $moan to true.
         # IOW, if we cant delete the renamed file at reboot its
         # not the end of the world. The other cases are more serious
@@ -277,7 +285,7 @@ sub _unlink_or_rename { #XXX OS-SPECIFIC
         _move_file_at_boot( $tmp, $file );
         return $tmp;
     } else {
-        _choke("Rename failed:$!", "Cannot procede.");
+        _choke("Rename failed:$!", "Cannot proceed.");
     }
 
 }
@@ -285,10 +293,14 @@ sub _unlink_or_rename { #XXX OS-SPECIFIC
 
 =pod
 
+=back
+
 =head2 Functions
 
 =begin _private
 
+=over
+
 =item _get_install_skip
 
 Handles loading the INSTALL.SKIP file. Returns an array of patterns to use.
@@ -360,7 +372,7 @@ Abstract a -w check that tries to use POSIX::access() if possible.
         my $dir=shift;
         unless (defined $has_posix) {
             $has_posix= (!$Is_cygwin && !$Is_Win32
-			 && eval 'local $^W; require POSIX; 1') || 0;
+             && eval 'local $^W; require POSIX; 1') || 0;
         }
         if ($has_posix) {
             return POSIX::access($dir, POSIX::W_OK());
@@ -380,7 +392,7 @@ be created first.
 
 Returns a list, containing: C<($writable, $determined_by, @create)>
 
-C<$writable> says whether whether the directory is (hypothetically) writable
+C<$writable> says whether the directory is (hypothetically) writable
 
 C<$determined_by> is the directory the status was determined from. It will be
 either the C<$dir>, or one of its parents.
@@ -474,7 +486,7 @@ sub _mkpath {
     } elsif ($show and $dry_run) {
         print "$_\n" for @make;
     }
-    
+
 }
 
 =pod
@@ -483,7 +495,7 @@ sub _mkpath {
 
 Wrapper around File::Copy::copy to handle errors.
 
-If $verbose is true and >1 then additional dignostics will be emitted.
+If $verbose is true and >1 then additional diagnostics will be emitted.
 
 If $dry_run is true then the copy will not actually occur.
 
@@ -528,28 +540,30 @@ sub _chdir {
 
 =pod
 
+=back
+
 =end _private
 
-=over 4
+=over
 
 =item B<install>
 
     # deprecated forms
     install(\%from_to);
-    install(\%from_to, $verbose, $dry_run, $uninstall_shadows, 
+    install(\%from_to, $verbose, $dry_run, $uninstall_shadows,
                 $skip, $always_copy, \%result);
 
-    # recommended form as of 1.47                
-    install([ 
+    # recommended form as of 1.47
+    install([
         from_to => \%from_to,
-        verbose => 1, 
+        verbose => 1,
         dry_run => 0,
         uninstall_shadows => 1,
         skip => undef,
         always_copy => 1,
         result => \%install_results,
     ]);
-    
+
 
 Copies each directory tree of %from_to to its corresponding value
 preserving timestamps and permissions.
@@ -572,22 +586,22 @@ without actually doing it.  Default is false.
 If $uninstall_shadows is true any differing versions throughout @INC
 will be uninstalled.  This is "make install UNINST=1"
 
-As of 1.37_02 install() supports the use of a list of patterns to filter out 
-files that shouldn't be installed. If $skip is omitted or undefined then 
-install will try to read the list from INSTALL.SKIP in the CWD. This file is 
-a list of regular expressions and is just like the MANIFEST.SKIP file used 
+As of 1.37_02 install() supports the use of a list of patterns to filter out
+files that shouldn't be installed. If $skip is omitted or undefined then
+install will try to read the list from INSTALL.SKIP in the CWD. This file is
+a list of regular expressions and is just like the MANIFEST.SKIP file used
 by L<ExtUtils::Manifest>.
 
-A default site INSTALL.SKIP may be provided by setting then environment 
-variable EU_INSTALL_SITE_SKIPFILE, this will only be used when there isn't a 
-distribution specific INSTALL.SKIP. If the environment variable 
-EU_INSTALL_IGNORE_SKIP is true then no install file filtering will be 
+A default site INSTALL.SKIP may be provided by setting then environment
+variable EU_INSTALL_SITE_SKIPFILE, this will only be used when there isn't a
+distribution specific INSTALL.SKIP. If the environment variable
+EU_INSTALL_IGNORE_SKIP is true then no install file filtering will be
 performed.
 
-If $skip is undefined then the skip file will be autodetected and used if it 
-is found. If $skip is a reference to an array then it is assumed the array 
-contains the list of patterns, if $skip is a true non reference it is 
-assumed to be the filename holding the list of patterns, any other value of 
+If $skip is undefined then the skip file will be autodetected and used if it
+is found. If $skip is a reference to an array then it is assumed the array
+contains the list of patterns, if $skip is a true non reference it is
+assumed to be the filename holding the list of patterns, any other value of
 $skip is taken to mean that no install filtering should occur.
 
 B<Changes As of Version 1.47>
@@ -595,32 +609,32 @@ B<Changes As of Version 1.47>
 As of version 1.47 the following additions were made to the install interface.
 Note that the new argument style and use of the %result hash is recommended.
 
-The $always_copy parameter which when true causes files to be updated 
-regardles as to whether they have changed, if it is defined but false then 
-copies are made only if the files have changed, if it is undefined then the 
+The $always_copy parameter which when true causes files to be updated
+regardless as to whether they have changed, if it is defined but false then
+copies are made only if the files have changed, if it is undefined then the
 value of the environment variable EU_INSTALL_ALWAYS_COPY is used as default.
 
-The %result hash will be populated with the various keys/subhashes reflecting 
+The %result hash will be populated with the various keys/subhashes reflecting
 the install. Currently these keys and their structure are:
 
     install             => { $target    => $source },
     install_fail        => { $target    => $source },
     install_unchanged   => { $target    => $source },
-        
+
     install_filtered    => { $source    => $pattern },
-    
+
     uninstall           => { $uninstalled => $source },
     uninstall_fail      => { $uninstalled => $source },
-        
+
 where C<$source> is the filespec of the file being installed. C<$target> is where
 it is being installed to, and C<$uninstalled> is any shadow file that is in C<@INC>
 or C<$ENV{PERL5LIB}> or other standard locations, and C<$pattern> is the pattern that
 caused a source file to be skipped. In future more keys will be added, such as to
-show created directories, however this requires changes in other modules and must 
+show created directories, however this requires changes in other modules and must
 therefore wait.
-        
-These keys will be populated before any exceptions are thrown should there be an 
-error. 
+
+These keys will be populated before any exceptions are thrown should there be an
+error.
 
 Note that all updates of the %result are additive, the hash will not be
 cleared before use, thus allowing status results of many installs to be easily
@@ -629,19 +643,19 @@ aggregated.
 B<NEW ARGUMENT STYLE>
 
 If there is only one argument and it is a reference to an array then
-the array is assumed to contain a list of key-value pairs specifying 
+the array is assumed to contain a list of key-value pairs specifying
 the options. In this case the option "from_to" is mandatory. This style
-means that you dont have to supply a cryptic list of arguments and can
+means that you do not have to supply a cryptic list of arguments and can
 use a self documenting argument list that is easier to understand.
 
 This is now the recommended interface to install().
 
 B<RETURN>
 
-If all actions were successful install will return a hashref of the results 
-as described above for the $result parameter. If any action is a failure 
-then install will die, therefore it is recommended to pass in the $result 
-parameter instead of using the return value. If the result parameter is 
+If all actions were successful install will return a hashref of the results
+as described above for the $result parameter. If any action is a failure
+then install will die, therefore it is recommended to pass in the $result
+parameter instead of using the return value. If the result parameter is
 provided then the returned hashref will be the passed in hashref.
 
 =cut
@@ -650,7 +664,7 @@ sub install { #XXX OS-SPECIFIC
     my($from_to,$verbose,$dry_run,$uninstall_shadows,$skip,$always_copy,$result) = @_;
     if (@_==1 and eval { 1+@$from_to }) {
         my %opts        = @$from_to;
-        $from_to        = $opts{from_to} 
+        $from_to        = $opts{from_to}
                             or Carp::confess("from_to is a mandatory parameter");
         $verbose        = $opts{verbose};
         $dry_run        = $opts{dry_run};
@@ -659,14 +673,14 @@ sub install { #XXX OS-SPECIFIC
         $always_copy    = $opts{always_copy};
         $result         = $opts{result};
     }
-    
+
     $result ||= {};
     $verbose ||= 0;
     $dry_run  ||= 0;
 
     $skip= _get_install_skip($skip,$verbose);
     $always_copy =  $ENV{EU_INSTALL_ALWAYS_COPY}
-                 || $ENV{EU_ALWAYS_COPY} 
+                 || $ENV{EU_ALWAYS_COPY}
                  || 0
         unless defined $always_copy;
 
@@ -684,7 +698,7 @@ sub install { #XXX OS-SPECIFIC
     my $cwd = cwd();
     my @found_files;
     my %check_dirs;
-    
+
     MOD_INSTALL: foreach my $source (sort keys %from_to) {
         #copy the tree to the target directory without altering
         #timestamp and permission and remember for the .packlist
@@ -736,7 +750,7 @@ sub install { #XXX OS-SPECIFIC
             }
             # we have to do this for back compat with old File::Finds
             # and because the target is relative
-            my $save_cwd = _chdir($cwd); 
+            my $save_cwd = _chdir($cwd);
             my $diff = 0;
             # XXX: I wonder how useful this logic is actually -- demerphq
             if ( $always_copy or !-f $targetfile or -s $targetfile != $size) {
@@ -745,28 +759,28 @@ sub install { #XXX OS-SPECIFIC
                 # we might not need to copy this file
                 $diff = compare($sourcefile, $targetfile);
             }
-            $check_dirs{$targetdir}++ 
+            $check_dirs{$targetdir}++
                 unless -w $targetfile;
-            
+
             push @found_files,
                 [ $diff, $File::Find::dir, $origfile,
                   $mode, $size, $atime, $mtime,
                   $targetdir, $targetfile, $sourcedir, $sourcefile,
-                  
-                ];  
+
+                ];
             #restore the original directory we were in when File::Find
-            #called us so that it doesnt get horribly confused.
-            _chdir($save_cwd);                
-        }, $current_directory ); 
+            #called us so that it doesn't get horribly confused.
+            _chdir($save_cwd);
+        }, $current_directory );
         _chdir($cwd);
-    }   
+    }
     foreach my $targetdir (sort keys %check_dirs) {
         _mkpath( $targetdir, 0, 0755, $verbose, $dry_run );
     }
     foreach my $found (@found_files) {
         my ($diff, $ffd, $origfile, $mode, $size, $atime, $mtime,
             $targetdir, $targetfile, $sourcedir, $sourcefile)= @$found;
-        
+
         my $realtarget= $targetfile;
         if ($diff) {
             eval {
@@ -778,15 +792,15 @@ sub install { #XXX OS-SPECIFIC
                     _mkpath( $targetdir, 0, 0755, $verbose, $dry_run );
                 }
                 print "Installing $targetfile\n";
-            
+
                 _copy( $sourcefile, $targetfile, $verbose, $dry_run, );
-                
-            
+
+
                 #XXX OS-SPECIFIC
                 print "utime($atime,$mtime,$targetfile)\n" if $verbose>1;
                 utime($atime,$mtime + $Is_VMS,$targetfile) unless $dry_run>1;
-    
-    
+
+
                 $mode = 0444 | ( $mode & 0111 ? 0111 : 0 );
                 $mode = $mode | 0222
                     if $realtarget ne $targetfile;
@@ -828,7 +842,7 @@ sub install { #XXX OS-SPECIFIC
 
 =item _do_cleanup
 
-Standardize finish event for after another instruction has occured.
+Standardize finish event for after another instruction has occurred.
 Handles converting $MUST_REBOOT to a die for instance.
 
 =end _private
@@ -975,7 +989,7 @@ sub install_default {
            $INST_SCRIPT => $Config{installscript},
            $INST_MAN1DIR => $Config{installman1dir},
            $INST_MAN3DIR => $Config{installman3dir},
-	   @INST_HTML,
+       @INST_HTML,
           },1,0,0);
 }
 
@@ -1021,7 +1035,7 @@ sub uninstall {
 
 Remove shadowed files. If $ignore is true then it is assumed to hold
 a filename to ignore. This is used to prevent spurious warnings from
-occuring when doing an install at reboot.
+occurring when doing an install at reboot.
 
 We now only die when failing to remove a file that has precedence over
 our own, when our install has precedence we only warn.
@@ -1040,17 +1054,17 @@ sub inc_uninstall {
     $ignore||="";
     my $file = (File::Spec->splitpath($filepath))[2];
     my %seen_dir = ();
-    
+
     my @PERL_ENV_LIB = split $Config{path_sep}, defined $ENV{'PERL5LIB'}
       ? $ENV{'PERL5LIB'} : $ENV{'PERLLIB'} || '';
-        
-    my @dirs=( @PERL_ENV_LIB, 
-               @INC, 
+
+    my @dirs=( @PERL_ENV_LIB,
+               @INC,
                @Config{qw(archlibexp
                           privlibexp
                           sitearchexp
-                          sitelibexp)});        
-    
+                          sitelibexp)});
+
     #warn join "\n","---",@dirs,"---";
     my $seen_ours;
     foreach $dir ( @dirs ) {
@@ -1090,7 +1104,7 @@ sub inc_uninstall {
         } else {
             print "Unlinking $targetfile (shadowing?)\n" if $verbose;
             eval {
-                die "Fake die for testing" 
+                die "Fake die for testing"
                     if $ExtUtils::Install::Testing and
                        ucase(File::Spec->canonpath($ExtUtils::Install::Testing)) eq ucase($targetfile);
                 forceunlink($targetfile,'tryhard');
@@ -1098,7 +1112,7 @@ sub inc_uninstall {
                 1;
             } or do {
                 $results->{fail_uninstall}{$targetfile} = $filepath;
-                if ($seen_ours) { 
+                if ($seen_ours) {
                     warn "Failed to remove probably harmless shadow file '$targetfile'\n";
                 } else {
                     die "$@\n";
@@ -1303,7 +1317,7 @@ always overwrite older identical files during the install process.
 
 Note that the alias EU_ALWAYS_COPY will be supported if EU_INSTALL_ALWAYS_COPY
 is not defined until at least the 1.50 release. Please ensure you use the
-correct EU_INSTALL_ALWAYS_COPY. 
+correct EU_INSTALL_ALWAYS_COPY.
 
 =back
 
